@@ -15,9 +15,9 @@
  */
 package jp.sf.pal.notepad.portlet;
 
-import jp.sf.pal.myfaces.portlet.MyFacesGenericPortlet;
+import org.seasar.teeda.core.portlet.FacesPortlet;
 
-public class NotepadPortlet extends MyFacesGenericPortlet
+public class NotepadPortlet extends FacesPortlet
 {
 
 }
